fit: Fit basic statistical models to climate data

Description Usage Arguments Value See Also Examples

View source: R/fit.climr.R

Description

Fit basic statistical models to climate data

Usage

1
fit(obj, fit_type = c("lm", "loess", "smooth.spline"))

Arguments

obj

An object of class climr from load_clim

fit_type

The type of model required, either linear regression (lm), loess, or smoothing spline (smooth.spline)

Value

Returns a list of class climr_fit which includes the model details as well as the data set and fit type used

See Also

load_clim, plot.climr_fit

Examples

1
2
ans1 = load_clim('SH')
ans2 = fit(ans1, 'lm')

RossElmes/climr documentation built on Oct. 30, 2019, 11:05 p.m.