load_clim: Load in climate data from NASA

Description Usage Arguments Value Examples

View source: R/load_clim.R

Description

Load in climate data from NASA

Usage

1
load_clim(type = c("GLB", "NH", "SH"))

Arguments

type

Either "GLB", "NH" or "SH" for global, northern or southern hemisphere temperature anomalies respectively

Value

A tibble which contains the yearly values, as well as which series was obtained (i.e. GLB, NH or SH)

Examples

1
data = load_clim(type = 'SH')

RossElmes/climr documentation built on Oct. 30, 2019, 11:05 p.m.