Description Usage Arguments Value See Also Examples
Fit basic statistical models to climate data
1 |
obj |
An object of class |
fit_type |
The type of model required, either linear regression ( |
Returns a list of class climr_fit which includes the model details as well as the data set and fit type used
1 2 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.